GOOF----LE-8-2.0-      ]  4        h
      ] g  guile	 	g  process-use-modules	 	 	g  srfi	g  srfi-13	 		 	
g  gnucash	g  printf	
 	
 	g   gnc-get-account-separator-string	g  qif-map-entry:gnc-name	g  hash-ref	g  gnc-account-lookup-by-full-name	g  qif-map-entry:allowed-types	g  xaccAccountGetType	g  xaccAccountGetCommodity	g  memv	g  gnc-commodity-equiv	g  xaccMallocAccount	g  gnc-get-current-book	g  throw	g  bug	f  qif-import:find-or-make-acct	f  .No valid account types allowed for account ~A.	g  GNC-STOCK-TYPE	g  GNC-MUTUAL-TYPE	g  gnc:string-rcontains	 g  xaccAccountBeginEdit	!g  xaccAccountSetName	"g  xaccAccountGetName	#g  xaccAccountSetDescription	$g  xaccAccountGetDescription	%g  xaccAccountSetType	&g  xaccAccountSetCommodity	'g  xaccAccountSetNotes	(g  xaccAccountGetNotes	)g  xaccAccountSetColor	*g  xaccAccountGetColor	+g  xaccAccountSetCode	,g  xaccAccountGetCode	-g  	substring	.g  
string-length	/g  qif-map-entry:description	0g  
string-append	1g  sprintf	2f   %a	3g  _	4f  /QIF import: Name conflict with another account.	5g  gnc-commodity-is-currency	6g  xaccAccountCommitEdit	7g  make-qif-map-entry	8g  qif-map-entry:set-qif-name!	9g  qif-map-entry:set-gnc-name!	:g   qif-map-entry:set-allowed-types!	;g  "qif-map-entry:allowed-parent-types	<g  qif-import:find-or-make-acct	=g  gnc-account-append-child	>g  	hash-set!	?g  gnc-get-current-root-account	@g  make-hash-table	Ag  gnc-commodity-table-find-full	Bg  gnc-commodity-table-get-table	Cg  GNC_COMMODITY_NS_CURRENCY	Dg  sort	Eg  length	Fg  
qif-file:xtns	Gg  gnc-progress-dialog-set-sub	Hf  "Preparing to convert your QIF data	Ig  	hash-fold	Jg  qif-map-entry:display?	Kg  for-each	Lg  qif-split:category-is-account?	Mg  qif-xtn:splits	Nf  Creating accounts	Og  gnc:substring-count	Pg  qif-import:get-account-name	Qg  qif-map-entry:qif-name	Rg  GNC-EQUITY-TYPE	Sg  gnc-progress-dialog-set-value	Tg  qif-import:check-pause	Ug  qif-import:canceled	Vg  cancel	Wf  #Matching transfers between accounts	Xg  qif-xtn:mark	Yg  qif-import:mark-matching-xtns	Zf  
Converting	[f   	\g  
qif-file:path	]g  xaccMallocTransaction	^g  xaccTransBeginEdit	_g  xaccTransSetCurrency	`g  qif-import:qif-xtn-to-gnc-xtn	ag  xaccTransCommitEdit	bg  gnc:backtrace-if-exception	cg  catch	dg  bad-date	eg  qif-import:qif-to-gnc	fg  xaccMallocSplit	gg  gnc-numeric-zero	hg  
qif-xtn:payee	ig  qif-xtn:number	jg  qif-xtn:action	kg  qif-xtn:security-name	lg  qif-xtn:default-split	mg  qif-xtn:date	ng  qif-xtn:from-acct	og  qif-xtn:cleared	pg  apply	qg  xaccTransSetDate	rg  qif-import:log	sf  qif-import:qif-xtn-to-gnc-xtn	tf  Missing transaction date.	ug  xaccTransSetDescription	vg  gnc-set-num-action	wg  qif-split:memo	xf   	yg  xaccTransSetNotes	zg  cleared	{g  xaccSplitSetReconcile	|g  
reconciled	}g  qif-xtn:share-price	~g  qif-xtn:num-shares	g  qif-split:amount g  qif-xtn:commission g  sell g  sellx g  shrsout g  gnc-numeric-add g  
GNC-DENOM-LCD g  gnc-numeric-sub g  gnc-numeric-mul g  GNC-DENOM-REDUCE g  gnc-numeric-zero-p g  gnc-numeric-div g  gnc:warn f  qif-import:qif-xtn-to-gnc-xtn:  f  splits in stock transaction! g  qif-split:accounts-affected g  string? g  string=? g  buy g  buyx g  reinvint g  reinvdiv g  reinvsg g  reinvsh g  reinvmd g  reinvlg g  xaccSplitSetAmount g  xaccSplitSetValue g  gnc-numeric-neg g  cgshort g  cgshortx g  cgmid g  cgmidx g  cglong g  cglongx g  intinc g  intincx g  div g  divx g  miscinc g  miscincx g  xin g  rtrncap g  rtrncapx g  xout g  miscexp g  miscexpx g  margint g  margintx g  shrsin g  stksplit g  gnc-numeric-create g  xaccAccountGetBalance g  qif-split:matching-cleared g  xaccSplitSetParent g  xaccSplitSetAccount g  qif-split:mark g  qif-split:category g  xaccSplitSetMemo g  string-prefix? f  **VOID** g  
xaccTransVoid f  QIF g  qif-import:mark-some-splits g  qif-split:miscx-category g  reverse g  qif-import:xtn-has-matches? g  qif-import:merge-and-mark-xtns g  
one-to-one g  many-to-one g  one-to-many g  gnc-numeric-equal g  default-stock-acct g  default-cgshort-acct g  default-cglong-acct g  default-cgmid-acct g  default-interest-acct g  default-margin-interest-acct g  default-capital-return-acct g  default-dividend-acct g  default-equity-holding g  default-commission-acct g  qif-xtn:mark-split g  qif-import:merge-xtn-info g  qif-split:set-matching-cleared! g  qif-xtn:set-payee! g  qif-xtn:address g  qif-xtn:set-address! g  qif-xtn:set-number! g  qif-split:set-mark! g  qif-xtn:set-mark! g  !gnc:account-tree-get-transactions g  xaccTransDestroy g  xaccAccountDestroy g  qif-import:qif-to-gnc-undoC 5 hpy     ] 4	 >  "  G  4
 >  "  G     hh   J  ] $   "  $  M 64  5$  $  
  " C$   C  "   B      g  
allowed-types
		e g  	currency?		e  g  filenamef  qif-to-gnc.scm
	q	
		r			s			r			r			v			w			x		!	y		$	v		%	{		*	{		1	{	.	3	{		7	{		=	~		@		,	J			M 		T 		W 		[ 	,	e 	 		e	  g  nameg  default-account-type C !"#$%&'()*+,-./0123456789:;<=> -  h  	  , 3 45 4 5	4	5
4	54 5HH
H"  
K
K"  $  (  ""  u4545$  J$  
4J5"  "  $  $  
4	5"  "  $  K
K45 K"  K
K"  "e" 4
45 5HHHHO Q 4
	5K4>  "  G  $  (  "  445>  "  G  445>  "  G  445>  "  G  445>  "  G  445>  "  G  445>  "  G  445>  "  G  "   J$  #4	
J5K4	45J5K"  	KJ
$ 4J>  "  G  4 5$  44 5>  "  G  "   4>  "  G  J$ J4	5(  "  "  4	4 5545(  "  V4545$  J$  
4J5"  "  $  $  
4	5"  "  $  	"t44 55"  	"Q4>  "  G  44!"5>  "  G  "   444 54#55>  "  G  "   4$>  "  G  J$  4%5 4&J>  "  G  4'J>  "  G  4( 45 >  "  G  4(4) 5>  "  G  4*5K"   "  4+>  "  7G  "  0J$  &J(  ""  4+J>  "  G  "  "4,	>  "  G  C
$  k
(  "  U4
54
5$  J$  
4J5"  "  $  $  
4	5"  "  $  
C""   	      g  	acct-info
	
 g  check-types?	
 g  	commodity		
 g  check-commodity?		
 g  default-currency		
 g  
gnc-acct-hash		
 g  old-root		
 g  new-root		
 g  sep		
 g  gnc-name			
 g  existing-account	
	
 g  same-gnc-account		*
 g  
allowed-types		3
 g  
make-new-acct	
	6
 g  incompatible-acct		9
 g  acc-type		k  g  
acc-commodity		k  g  new-acct	  g  parent-acct	  g  parent-name	  g  	acct-name	  g  last-sep	  g  default-account-type	  g  
short-name	q< g  count	1 g  	test-name	1 g  	test-acct	. g  acc-type	 g  
acc-commodity	 g  new-name	<n g  pinfo	/ g  acc-type	 g  
acc-commodity	  !g  filenamef  qif-to-gnc.scm
	&
		)			)			*			)			+			)		"	-	
	*	)		-	/	
	3	)		B	_	
	E	`	
	I	N		U	N		^	4		e	5		k	4		u	7			x	8		|	8	
	}	9	 	6	 	;		 	<	
 	O	 	S	 	T	 	V	 	V	 	U	 	[	 	\	 	h	 	h	+ 	h	 	h	 	 	
 	
) 	
/ 	4 	9 	D 	M 	R 	] 	f 	k 	v 	 	 	 	 	 	 	 	 	 	 	 	 	 	
 	" 	 	  	7 	4	 	  	 	 	
 	. 	8 	9 	> 	I 	V 	o 	q 	$t	@		@		A	
	C		C	-	C	9	C	-	C		B		E		B		F		4		5		4		7			8		8	
	9		6		;			<	
		F	/
	F		G		G		H		H	,!	H	8%	H	,'	H	1	A	
< 	? 	S 	X 	\ 	^ 	c 	s 	x 	${ 	& 	& 	$ 	 	
 	
 	 	 	 	 	 	! 	 	 	 	 	 	", 	8 	O 	
[ 	d 	 	
	e		e	
	4		5		4		7			8		8	
	9		6		;			<	
	e	 	
	  g  nameg  qif-import:find-or-make-acct C<R?@ABCDEF      h       ]44 554455C           g  a
		 g  b		  g  filenamef  qif-to-gnc.scm
 	(	 	-	 	5	 	-	 	-	 	5	 	-	 	* 				   CG3HIJ  h       ]45$  M N "   C             g  k
		 g  v		 g  p			  g  filenamef  qif-to-gnc.scm
			
	
						
 			   CJ      h       ]45$  M N "   C             g  k
		 g  v		 g  p			  g  filenamef  qif-to-gnc.scm
 		!	
	
!			#		"	
 			   CJ      h       ]45$  M N "   C             g  k
		 g  v		 g  p			  g  filenamef  qif-to-gnc.scm
(		)	
	
)			+		*	
 			   CEKKLM     hH   	  ]	MN"  ,45$   M N MNC(  C"4 5"          g  xtn
		D g  splits		7  g  filenamef  qif-to-gnc.scm
5	
	6		6		7		8		8	2	8		8		:	(	:		!;	%	#;		(<	"	,<		1=	!	7=		77		87	$	D7	 		D   CF  h   k   ]L LO 4 56  c       g  qif-file
		  g  filenamef  qif-to-gnc.scm
3		>	
	4		 		   CNO   h       ]44 5L 5445L 5C       g  a
		  g  b		   g  filenamef  qif-to-gnc.scm
M		N		N	,	N		P		P	,	P		N	 			 	   CPQRSTUV<5      h8  '  ]!L $  4L 44 555"  4 54545$  "  	45MNL$  XM	
$  I4	LMM>  "  G  4
L>  "  G  $  4
>  "  G  "   "   "   "   LLLLL6"  6$  ,$  "  45$   LLLL6""$  $   LLLL6""          g  acctinfo
	4 g  security	 4 g  ok-types		)4 g  equity?		44 g  t		?	Y g  stock?		Y4  g  filenamef  qif-to-gnc.scm
U		W			X		Y	 	Z	!	Y	 	X		 V			#[		)V			,\		4V			7]		?]		N^		YV			^		`		f		k		l		q		r			{
	- 		 	 	 
	 
	 
	 m	 a	 g	  h	$ g	i	a	a	,b	 (	4   CWSTUVXYG03Z[\KSTUVX]^_`a 
     h   F  ]	M	N	L$  XM		
$  I4LM	M>  "  G  4L>  "  G  $  4>  "  G  "   "   "   4 5$  C445 54	>  "  G  4
L>  "  G  4 L LLLLLL>	  "  G  6    >      g  xtn
	  g  gnc-xtn	|   g  filenamef  qif-to-gnc.scm
	
					
											"
	-	'			0		G		H
		L
		Q
		f		p		s		v	 	|		|			 	 	 	 	    CF 
    hX      ]L$  +4L4454 55>  "  G  "    LLLLLLLLL O 
4	 56        g  qif-file
		W  g  filenamef  qif-to-gnc.scm
							
		*		9		<		9		J		5	"	*	'	
	O	
	W		 		W   C !       hp    ]`45  445 54	545 4445 5L 5HH4	L
5
H
H	L$  4L4
5>  "  G  "   4O L>  "  G  4O L>  "  G  4O L>  "  G  4J5K4O L>  "  G  L$  4L45>  "  G  "   4	JO 5K4L L	O J>  "  G  L$  4L45>  "  G  "   4J5$  "  J	K	L$  XJ		
$  I4LJ	J>  "  G  4L>  "  G  $  4>  "  G  "   "   "   4
5$  "  4
>  "  G  (  "  
"aJJ
"S"   4 	LLLLLO 	>  "  G  L$  4L>  "  G  "   C        g  old-root
	n g  new-root	n g  
gnc-acct-hash		n g  sep		#n g  default-currency		8n g  sorted-accounts-list		;n g  
markable-xtns		>n g  sorted-qif-files-list		In g  
work-to-do		Ln g  	work-done			On g  xtn	
t g  rest	t  g  filenamef  qif-to-gnc.scm
 		 		 		
 		
 	(	 		 		 		 		 		# 		& 	
	) 		, 	-	2 		8 	
	8 		; 	!	; 		> 		> 		A 	"	I 		W		X	
	]	&	a	)	c	&	h	
	u	 	 '	 .	 .	 2	 C	 D	
 E	' E	* E	' D	

L	K	T	Ft	Gu	
Lv	$Pv	'Rv	$Wu	
dw	
lw	
pw	tx	
w	y							
	-				
	
	
	}	}	~					"	x	
x	y	!x	
&	T	U	
 T	n
  g  nameg  private-convert CbcVcd      h   g   - 1 3  C    _       g  key
			 g  args			  g  filenamef  qif-to-gnc.scm
	0 			
   C      h   T   ] L 6    L       g  filenamef  qif-to-gnc.scm
	
				 		
   C  h   g   - 1 3 C     _       g  key
			 g  args			  g  filenamef  qif-to-gnc.scm
	
 			
   C      h   T   ] L O 6       L       g  filenamef  qif-to-gnc.scm
			
		 		
   C h8   o  , 3 	O  Q O 6     g      g  qif-files-list
		3 g  qif-acct-map		3 g  qif-cat-map			3 g  qif-memo-map			3 g  	stock-map			3 g  default-currency-name			3 g  transaction-status-pref			3 g  progress-dialog			3 g  private-convert			3  	g  filenamef  qif-to-gnc.scm
 
	3	 		3	  g  nameg  qif-import:qif-to-gnc CeRMfghijklmnopqrs3tduvwxyz{|}~EKfwgxLEz{| hX    ]I4 5$  C445 54 5L	$  4 5"  4 5HHHHJ$  "  45 KM J	4	
	5	N 4
J45>  "  G  4J45>  "  G  $  4
>  "  G  "   45$  "  4 5$  4L5K"  45$  4L5$  k4L5$  4L5$  "  	4LL5"  $  "  +4M5$  4M5$  "  	4LM5"  "  +45$  45$  "  	4L5"  KJ$  "  4L5K"  4L5K4J5K4LJ5K4 5&  4c>  "  G  "   &  4y>  "  G  "   4J>  "  G  L6           g  	qif-split
	S g  
gnc-far-split	<S g  
far-acct-info		<S g  
far-acct-name		<S g  far-acct		<S g  	split-amt		<S g  memo		<S g  cat		<S g  a		_	u g  b			_	u g  n		~  g  n	   g  t	F g  cleared	7  g  filenamef  qif-to-gnc.scm
				
	
		&		'		&		"	)		*		6 		<		P"		U"	7	["	'	_&	*	d		w&		x'		~'	4 	 '	 (	 (	5 	 (	 *	 *	 /	 /	- /	 /	 0	 -	 1	) 1	4	4	(
4	-	?	"?	?	@	(&@	#'A	--A	A/A	-3@	#9B	(F@	UC	(_C	#`D	-fD	@hD	-lC	#rE	(F	$F	G	)G	8G	)F	H	$>	I	J	-J	5	)5	L	'L	M	"M	P	"P	Q	Q	R	S	S	T	8W	SX	 U	S   C `      h    , 	3 +4 5445 545 4 54 54 54 54	 54
 54 54 5HHH
HH
	$  4
4
 5>  "  G  "  3445>  "  G  4>  "  G  $  4>  "  G  "   $  4
>  "  G  "   $  
45K"  44 55KJ$  D$  	"  $  4J>  "  G  "  4J>  "  G  "   &  4
c>  "  G  "  4&  4
y>  "  G  "  4
>  "  G  $ 4 5H4 5HH44 55HHHHH H!H"H#4  5$H%445 5&J$  "  45 K$  W$$  I!$  "  "$  "  #$  4$$
%5K"  4&$
%5K"  K"  -J$   JJ('4''(
(5'(K"  45 KJ$  9$  /4)J5$  "  JJ('4*'(
(5'(K"   "  45 K4+	5$  4,-.>  "  G  "   4/4 5 5KJKJKJKJ$  J$  40J5''$  '"  	40J5'K41J5K
40J
5K42J5''$  "  	43J5'$  9404 55''$  '"  4044 555'K "   J $  "  %40J5''$  '"  	40J5'K 41J 5K!40J!5K""   "   4$  "  Y5$  "  K6$  "  =7$  "  /8$  "  !9$  "  :$  "  ;$  oJ$  "  45 K4<
J>  "  G  4=
J>  "  G  4=&4>5>  "  G  4<&4>5>  "  G  " !$  "  "$  }J$  "  45 K4<
J'4>'5'>  "  G  4=
J'4>'5'>  "  G  4=&>  "  G  4<&>  "  G  " V?$  "  @$  "  A$  "  B$  "  C$  "  D$  "  uE$  "  gF$  "  YG$  "  KH$  "  =I$  "  /J$  "  !K$  "  L$  "  M$  ^4=
>  "  G  4<
>  "  G  4=&4>5>  "  G  4<&4>5>  "  G  " +N$  "  /O$  "  !P$  "  Q$  "  R$  ^4=
4>5>  "  G  4<
4>5>  "  G  4=&>  "  G  4<&>  "  G  " S$  ^4<
J>  "  G  4=
J>  "  G  4=&4>5>  "  G  4<&4>5>  "  G  " %#$  l4<
J'4>'5'>  "  G  4=
J'4>'5'>  "  G  4=&>  "  G  4<&>  "  G  "  T$  J4U	
5('4*'(
(5'('4VJ5(4'('
(5)4<
)>  "  G  4<&4>(5>  "  G  4=
J*4>*5*>  "  G  4=&J>  "  G  )('"   4W4 55''&  4&c>  "  G  "   '&  4&y>  "  G  "   'J$  X40J5''$  '"  	40J5'''$  41'5"  (($  40(5K#"   ('"   $$  BJ#$  8445 5K%4=J%$>  "  G  4<J%$>  "  G  "   "   J$  J$  4X
>  "  G  4Y
J>  "  G  4X&>  "  G  4Y&J">  "  G  J%$  ,4XJ%>  "  G  4YJ%J#>  "  G  "   "   "   &%$#"! "  405K41J5K
40J
5K4Z[	O 
	>  "  G  4=
J>  "  G  4<
J>  "  G  4X
>  "  G  4Y
J>  "  G  425$  )4\]5$  4^_>  "  G  "   "   C            g  qif-xtn
	 g  qif-file	 g  gnc-xtn		 g  
gnc-acct-hash		 g  qif-acct-map		 g  qif-cat-map		 g  qif-memo-map		 g  transaction-status-pref		 g  progress-dialog		 g  splits			X g  gnc-near-split	
	X g  near-split-total		X g  near-acct-info		X g  near-acct-name	
	X g  	near-acct		X g  	qif-payee		X g  
qif-number		X g  
qif-action		X g  qif-security		X g  qif-default-split		X g  qif-memo		X g  qif-date		X g  
qif-from-acct		X g  qif-cleared		X g  share-price	
 g  
num-shares	
 g  	split-amt	
 g  xtn-amt	
 g  	qif-accts	
 g  
qif-near-acct	
 g  qif-far-acct	
 g  qif-commission-acct	
 g  
far-acct-info	 
 g  
far-acct-name	!
 g  far-acct	"

 g  commission-acct	#

 g  commission-amt	$
 g  commission-split	%
 g  
gnc-far-split	&%
 g  a	' g  b	( g  a	' g  b	( g  t	'e g  t	' g  t	' g  t	'  g  n	'GS g  n	'gs g  n	' g  n	'
 g  a	'e{ g  b	(e{ g  
splitratio	'{ g  	in-shares	( g  
out-shares	) g  n	* g  cleared	'		T g  t	'	c	} g  commission-acct-info	'	}	 g  commission-acct-name	(		  =g  filenamef  qif-to-gnc.scm

						)					 		'		.		5		<		D		K		R		X		|		}	 	( 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 				!	$	++	&-	/	5	;	?	$@	E	I	
J	b	} 	 							e	e	f	e	h	h	/h	*h	e	q	e	s	s	/%s	%e	-u	
2u	08u	>x	
Dz	M{	j	w}	|					"			"		
		$		$			 					
			!	.	1	28	-<	>	
A	C	
F	I	
L	$P	
V	
\	]	e	t			%		 						/				5				(	/	*	(						"	#	$+	,	6	G	
	
	5	#	
	
	
		
	
		
!	
5	
:	5@	#A	
G	0J	X	
a	
g	/j	x	
	
	
	
z	
	
	
		
	
		
	
	
	)	
2	
7	B	
K	
_	
	
	
	
	
		
	
		
	
	
	0		
	

	/		
'	
;	
[	
^	/e	 j	{	
~		
		
						1								
					
							3		9		:		Z	
	[ 		c 		r		}																
					'		(		'			
			
 	

	
	
	
/	
C	
\	
]	
q	

	

	

	
	

	
	

	
\	
 ]	
4^	
H_	
\	
f	g 	
k 	o 	
s	t!	z!	!	(			  g  nameg  qif-import:qif-xtn-to-gnc-xtn C`RLM       h`   ]  ]
"  MJ(  "  34J5$  "  4J5$  4J 5K"  JKJ(  CJH"4 5H"U      g  xtn
		` g  candidate-xtns		` g  splits-left			S  g  filenamef  qif-to-gnc.scm
-
	.		4		5		5	&	5		5		"6		'6	1	)6		-5		.8		:7		A:		C:		I<		S=		S.		T.		`.	 		`	  g  nameg  qif-import:mark-matching-xtns CYRmkjngKL h`      ]"  	 M N C4 5$  @4M4 55$  * MNM4 54
5NC""         g  s
		^ g  a	<	R g  b		<	R  g  filenamef  qif-to-gnc.scm
e		m		
l		f	
	f		f	
	g		 g	.	(g		,f		1j		3i		6k	9	<k	&	AH		Tk	 		^   CX !      h    ]s HH454545HH45	45
HHH
H	$ 845KK K
$ 
$  "  Y
$  "  K
	$  "  =

$  "  /
$  "  !
$  "  

$  "  
$  &J45K45K45K"  y
$  "  
$  &J45K45K45K"  <
$  45K45K"  
$  J45K"   "   "  J45K45K45 K4O  >  "  G  4J5K4J5K"  45$  "  445J5$  <4JJJ5K
J
$   4JJ
>  "  G  K"   "   J$  "  $  	""  "wJ
$  .J
$  "  $   C $  JCC C             g  splits
	 g  xtn	 g  candidate-xtns		 g  split		 g  near-acct-name		 g  
far-acct-name		 g  date		 g  n			) g  amount		) g  group-amount		, g  
security-name			5 g  action	
	> g  different-acct-splits		A g  same-acct-splits		D g  how	
	G g  done		J g  	qif-accts		[ g  n	   g  n	+ g  n	my g  xtns	Y g  key	j  g  filenamef  qif-to-gnc.scm
F
	L		G		O		G		P		P		 G		)G		/R		5G		8S		>G		AU	 	AG		DV		DG		RZ		Sv		[u		`w		bw	
	ex		hx	
	my	!	oy	
	uz	
	~~	 	 G	 	 	& 	 	%	~		"G	-	.	&6	7	%?	L~	M	&U	V	%^	k~	m	pG	{	\	\	
]	]	
^	^	
d	
p	!p	
q	&q	
			"		
			,					/					2%	0	>	
F	G	H	L	O	U	
Y	g	j	j				 b		  g  nameg  qif-import:mark-some-splits CRgmELkjM       hP    ]]45 4 5$  a$  U45	&  C45	&  1$  !$  "  "  "  "  "  "  HHH$ " 	
4
5$ Q45$ B44
55$ ,4
54	 54
 5
H$  
$  
$  "  Y
$  "  K

$  "  =
$  "  /
$  "  !
$  "  
$  "  
$  J45K"   "   "   4J5$  

 K"  W"  '
JKJJ4
5K"  ,$  "4J5$  

 K"  ""  "
"   "   "   J$  "  	$  			""  
4 5	"nJ$  "  	4J5$  JK"   "   JC          g  xtn
	L g  	acct-name	L g  date		L g  amount		L g  	group-amt		L g  	self-date			~ g  same-acct-splits		~L g  this-group-amt		~L g  how		~L g  date-matches		~L g  splits-left		  g  split	
  g  this-amt	  g  	stock-xtn	  g  action	
  g  n	Q] g  a	 g  b	  g  filenamef  qif-to-gnc.scm

					
											 		!		-		.		:		=		@	#	A		E		H		L	$	N		R		U		Z	%	]		~	 	 	
 	 	 	 	 	 	 	 	! 	 	 	" 	# 	  	 	 	 	Q	*T	_	l	x	z	"	.		-						%		"	/			# 						
	("	
(	.	:	
<	?	A	 P	L	  g  nameg  qif-import:xtn-has-matches? CRkjnM 3 h    ]2454545HHH$ H$  "  $  "  $  "  $  "  u$  "  g	$  "  Y
$  "  K$  "  =$  "  /
$  "  !$  "  $  "  $  45K" 7$  "  $  "  u$  "  g$  "  Y$  "  K$  "  =$  "  /$  "  !$  "  $  "  $  K"  $  "  K$  "  =$  "  / $  "  !!$  "  "$  "  #$  4$4%55K"  *&$  "  '$  4(4%55K"   $  "  $  K" $  "  Y$  "  K$  "  =&$  "  /$  "  !'$  "  $  "  $  4$4%55K" $  45K" $  "  !$  "  
$  "  $  4)5K" >$  "  $  "  $  4*5K" 
$  "   $  "  
$  4+5K"  $  "  !$  "  $  4,5K"  $  "  #$  
4-5K"  ~$  "  "$  4.5K"  X$  "  $  "  	$  4/5K"  $$  "  $  
405K"   415$  
425K"   "  
K4$ 5KJJJ C           g  split
	 g  xtn	 g  near-acct-name		 g  
far-acct-name		 g  commission-acct-name		 g  security		 g  action		 g  	from-acct		  g  filenamef  qif-to-gnc.scm

			
				 		,		5	
 	" 	
 	
	
	
		,	'		
	
 	 	2 	- 		
,%	
>'	
K%	
*	*	,*	'*	)	
%	
,	!,	
%	
/	.	
#%	
@2	J1	
W%	
t5	~4	
%	
8	7	
%	
;	:	
%	
>	=	
	%	
&A	0@	
=%	
LD	TC	
YG	cG	
dI	lH	x	
y		
K	 C		  g  nameg  qif-split:accounts-affected CRjkKo   h   d   ] 4L 56 \       g  s
		  g  filenamef  qif-to-gnc.scm
e		f	-	f	
 		   Co  h   d   ] 4L 56 \       g  s
		  g  filenamef  qif-to-gnc.scm
o		q	
	p	
 		   CEMo   hP  k  ]<4 5454 545
		$  54 >  "  G  4 >  "  G   O 
6	$  64
>  "  G  4 >  "  G  	O 64
4 554
455$  64 >  "  G  4 >  "  G  
4
 564
4 554
455$  64
>  "  G  4 >  "  G  4
56$  "  
$  "  $  64 >  "  G  4 >  "  G  
4
 56"  64
>  "  G  4 >  "  G  4
56$ \$  "  $  64
>  "  G  4 >  "  G  4
56$ $ $  "  $  "  u$  "  g$  "  Y$  "  K$  "  =$  "  /$  "  !$  "  $  "  $  64 >  "  G  4 >  "  G  
4
 564
>  "  G  4 >  "  G  4
56"l"h"d      c      g  xtn
	J g  splits	J g  	other-xtn		J g  how		J g  action		'J g  o-action		'J g  security		'J g  
o-security		'J g  split		'J g  
match-type			'J g  match-splits	
	'J  g  filenamef  qif-to-gnc.scm
T
	V		
W		X		Y		!Z		$[		'\		'V		>]		?b		Sc		sd		|]		}l	 l	% l	 m	 n	 {	 {	 {	 |	 |	 |	 {		 v	 }	 ~	 	 	#										"v	#	*	-/	8	P	X	^		tv	u					
				
	(	
	
		
v						'				)	1		7		F					
 	 				*		6	>	 Q	J	  g  nameg  qif-import:merge-and-mark-xtns CRhi  h   L  ]4 5$  ,45$  "  44 5>  "  G  "   4 5$  ,45$  "  44 5>  "  G  "   4 5$  45$  C4 56C D      g  from-xtn
	  g  to-xtn	   g  filenamef  qif-to-gnc.scm

			
								"	!	-		:		D		E		O		T		Y	#	d		q		{		|	 	 	" 	 	 	  g  nameg  qif-import:merge-xtn-info CRM     h`   J  ]4>  "  G  H"  '45$  (  "  "K"  
4 5"J$   6C B      g  xtn
		_ g  split		_ g  
all-marked			_ g  splits			C  g  filenamef  qif-to-gnc.scm

									"		$		(		+		/	
	6		<		?	
	C		D		P		V		]	 		_	  g  nameg  qif-xtn:mark-split CRK        h   ]   ] 6U       g  elt
		  g  filenamef  qif-to-gnc.scm
			 		   C     h@      ]	 $  54 54>  "  G  4 >  "  G   6C        g  root
		? g  txns		=  g  filenamef  qif-to-gnc.scm

										&		=	 		?  g  nameg  qif-import:qif-to-gnc-undo CRC        g  filenamef  qif-to-gnc.scm		
		
	&
)2 
N
P`-
ZF
bN
k
tT
v
w
ym
 	yo
   C6 